@@ -6,12 +6,13 @@ import json
 import os
 import sqlite3
 from abc import ABC, abstractmethod
-from typing import Dict, List, Optional
+from typing import Dict, List, Optional, Union
 
 import psycopg2
 import pytz
 from skit_fixdf.fix import datetime as fix_dt
 
+from skit_labels import constants as const
 from skit_labels.types import (
     AudioSegmentTask,
     CallTranscriptionTask,
@@ -99,14 +100,29 @@ class Database:
     Class holding connection with backend database.
     """
 
-    def __init__(self):
-        self._initialize()
+    def __init__(
+        self,
+        db: Optional[str] = None,
+        user: Optional[str] = None,
+        password: Optional[str] = None,
+        host: Optional[str] = None,
+        port: Optional[Union[int, str]] = None,
+    ):
+        self._initialize(db=db, user=user, password=password, host=host, port=port)
 
-    def _initialize(self):
-        host = os.getenv("TOGDB_HOST")
-        user = os.getenv("TOGDB_USER")
-        password = os.getenv("TOGDB_PASS")
-        port = os.getenv("TOGDB_PORT", "5432")
+    def _initialize(
+        self,
+        db: Optional[str] = None,
+        user: Optional[str] = None,
+        password: Optional[str] = None,
+        host: Optional[str] = None,
+        port: Optional[Union[int, str]] = None,
+    ):
+        db = db or os.getenv(const.TOGDB_DB, "tog")
+        user = user or os.getenv(const.TOGDB_USER)
+        password = password or os.getenv(const.TOGDB_PASSWORD)
+        host = host or os.getenv(const.TOGDB_HOST, "localhost")
+        port = port or os.getenv(const.TOGDB_PORT, "5432")
 
         if password is None:
             raise ValueError(
@@ -114,7 +130,7 @@ class Database:
             )
 
         self.conn = psycopg2.connect(
-            host=host, database="tog", user=user, password=password, port=port
+            host=host, database=db, user=user, password=password, port=port
         )
 
     def list_jobs(self) -> List[Dict]:
@@ -164,17 +180,37 @@ class Job(AbstractJob):
     A Tog job which specifies a kind of tagging data set and problem.
     """
 
-    def __init__(self, id: int, task_type="conversation", database=None, tz=pytz.UTC):
+    def __init__(
+        self,
+        id: int,
+        task_type="conversation",
+        database: Optional[str] = None,
+        tz=pytz.UTC,
+        start_date: Optional[str] = None,
+        end_date: Optional[str] = None,
+        db: Optional[str] = None,
+        user: Optional[str] = None,
+        password: Optional[str] = None,
+        host: Optional[str] = None,
+        port: Optional[Union[str, int]] = None,
+    ):
         self.id = id
         # TODO: Check task validity right here
         self.task_type = task_type
 
-        self.db = database or Database()
+        self.db = database or Database(
+            db=db, user=user, password=password, host=host, port=port
+        )
         self._fetch_details()
 
         # Cache for keeping rows of job indexed by data_ids
         self.cache = {}
         self.tz = tz
+        self.start_date = start_date
+        self.end_date = end_date
+
+    def __repr__(self):
+        f"Job {self.id}: {self.name} [language: {self.lang}]\n{self.description}"
 
     def _fetch_details(self):
         """
@@ -193,20 +229,30 @@ class Job(AbstractJob):
             except TypeError:
                 raise ValueError("Invalid job id")
 
-    def total(self, untagged=False):
+    def total(self, untagged=False, start_date=None, end_date=None):
         """
         Return total number of items for this job. If `untagged` is True, consider
         untagged items in counting too.
         """
+        start_date = start_date or self.start_date
+        end_date = end_date or self.end_date
 
         with self.db.conn.cursor() as cur:
             cur.execute(
-                f"SELECT count(*) FROM jobs_task WHERE job_id = {self.id} {'' if untagged else 'AND tag IS NOT NULL'}"
+                f"""
+                SELECT count(*) FROM jobs_task INNER JOIN jobs_data ON
+                    jobs_data.id = jobs_task.data_id
+                WHERE
+                    jobs_task.job_id = {self.id}
+                    {'' if untagged else 'AND jobs_task.tag IS NOT NULL'}
+                    {f"AND jobs_data.created_at >= '{start_date}'" if isinstance(start_date, str) else ''}
+                    {f"AND jobs_data.created_at < '{end_date}'" if isinstance(end_date, str) else ''}
+                """
             )
             n = cur.fetchone()[0]
         return n
 
-    def get_by_data_id(self, id: int, cache=True):
+    def get_by_data_id(self, id: int, cache=True, start_date=None, end_date=None):
         """
         Return task and tag using the data id
         """
@@ -214,16 +260,26 @@ class Job(AbstractJob):
         if id in self.cache:
             return self.cache[id]
 
+        start_date = start_date or self.start_date
+        end_date = end_date or self.end_date
+
         with self.db.conn.cursor() as cur:
             cur.execute(
-                f"""SELECT
-              jobs_data.data, jobs_task.tag, jobs_task.is_gold, jobs_task.tagged_time
+                f"""
+            SELECT
+                jobs_data.data,
+                jobs_task.tag,
+                jobs_task.is_gold,
+                jobs_task.tagged_time,
+                jobs_data.id
             FROM jobs_task INNER JOIN jobs_data ON
-              jobs_data.id = jobs_task.data_id
-            WHERE jobs_task.job_id = {self.id} AND jobs_data.data_id = '{id}'
+                jobs_data.id = jobs_task.data_id
+            WHERE
+                jobs_task.job_id = {self.id} AND jobs_data.data_id = {id}
+                {f"AND jobs_data.created_at >= '{start_date}'" if isinstance(start_date, str) else ''}
+                {f"AND jobs_data.created_at < '{end_date}'" if isinstance(end_date, str) else ''}            
             """
             )
-
             try:
                 task_dict, tag_list, is_gold, tagged_time = cur.fetchone()
             except TypeError:
@@ -264,6 +320,9 @@ class Job(AbstractJob):
         for checking, say, production metrics. If `only_gold` is True, return
         only items which are marked as gold.
         """
+        start_date = start_date or self.start_date
+        end_date = end_date or self.end_date
+
         query = f"""
         SELECT
             jobs_data.data,
